@@ -154,7 +154,6 @@ class FieldsTestCase(unittest.TestCase):
         with app.test_request_context("/"):
             self.assertEquals("/3", field.output("hey", Foo()))
 
-
     def test_int(self):
         field = fields.Integer()
         self.assertEquals(3, field.output("hey", {'hey': 3}))
@@ -212,6 +211,10 @@ class FieldsTestCase(unittest.TestCase):
         field = fields.Fixed()
         self.assertRaises(MarshallingException, lambda: field.output("hey", {'hey': 'NaN'}))
 
+    def test_fixed_with_attribute(self):
+        field = fields.Fixed(4, attribute="bar")
+        self.assertEquals('3.0000', field.output("foo", {'bar': '3'}))
+
 
     def test_string(self):
         field = fields.String()
@@ -271,6 +274,14 @@ class FieldsTestCase(unittest.TestCase):
         field = fields.List(fields.String)
         self.assertEquals(['a', 'b', 'c'], field.output('list', obj))
 
+    def test_list_with_attribute(self):
+        class TestObject(object):
+            def __init__(self, list):
+                self.foo = list
+        obj = TestObject(['a', 'b', 'c'])
+        field = fields.List(fields.String, attribute='foo')
+        self.assertEquals(['a', 'b', 'c'], field.output('list', obj))
+
     def test_null_list(self):
         class TestObject(object):
             def __init__(self, list):
